/***************************************************************************
*  PROGRAM: qidx-db.p
*   AUTHOR: Stephen Hawkins
*     DATE: 26 March 2006
* INCLUDES: qidx-tt.i
*   RUN BY: qidx.p
*  PURPOSE: To copy table definition data from schema tables in the
*           currently selected database to temp-tables for use in qidx.p.
*           If p-file-name = "*" then definition data will be copied for all
*           tables in the database, otherwise just for the specified table.
***************************************************************************/

{qidx-tt.i "shared"}

def input param p-db-name as char.
def input param p-file-name as char.

def var table-name as char.
def var index-order as int.
def var field-order as int.

/* COPY SCHEMA INFO FROM DB TO TEMP-TABLES */
for each dictdb._file where 
         dictdb._file._file-name = p-file-name or p-file-name = "*"
         no-lock:
  table-name = p-db-name + "." + _file._file-name.

  /* COPY TABLE INFO FROM DB TO T-TABLE */
  create t-table.
  assign
    t-table.db-name = p-db-name
    t-table.file-name = _file._file-name
    t-table.table-name = table-name
    t-table.from-db = yes
    t-table.modified = no
    index-order = 0.
  
  /* COPY FIELD INFO FROM DB TO T-FIELD */
  for each dictdb._field of _file no-lock:
    create t-field.
    assign
      t-field.table-name = table-name
      t-field.field-name = _field._field-name
      t-field.data-type = _field._data-type
      t-field.extent = _field._extent.
  end.
  
  /* COPY INDEX INFO FROM DB TO T-INDEX */
  for each dictdb._index of _file no-lock:
    create t-index.
    assign
      t-index.table-name = table-name
      index-order = index-order + 1
      t-index.index-order = index-order
      t-index.index-name = _index._index-name
      t-index.index-type = 
        (if _index._unique then "U" else
         if _index._wordidx <> ? then "W" else
         if _index._index-name = "default" then "D" else "N")
      t-index.num-fields = _num-comp
      field-order = 0.

    /* CHECK IF PRIMARY INDEX */
    if _file._prime-index = recid( _index ) then
      t-table.primary-index = t-index.index-name.
    
    /* COPY INDEX-FIELD INFO FROM DB TO T-IXFLD */      
    for each dictdb._index-field of _index no-lock, 
        each dictdb._field of _index-field no-lock:
      create t-ixfld.
      assign
        t-ixfld.table-name = table-name
        t-ixfld.index-name = t-index.index-name
        field-order = field-order + 1
        t-ixfld.field-order = field-order
        t-ixfld.field-name = _field._field-name
        t-ixfld.is-ascending = _index-field._ascending
        t-ixfld.is-word = t-index.index-type = "W".
    end.
    
  end. /* for each _index */

end. /* for each _file */


/**************************************************************************/
